@@ -15,23 +15,23 @@ import sys
 from typing import Dict, List
 
 from .literals import (
-    ArrayJobDependency,
-    AssignPublicIp,
-    CEState,
-    CEStatus,
-    CEType,
-    CRAllocationStrategy,
-    CRType,
-    DeviceCgroupPermission,
-    EFSAuthorizationConfigIAM,
-    EFSTransitEncryption,
-    JobStatus,
-    JQState,
-    JQStatus,
-    LogDriver,
-    PlatformCapability,
-    ResourceType,
-    RetryAction,
+    ArrayJobDependencyType,
+    AssignPublicIpType,
+    CEStateType,
+    CEStatusType,
+    CETypeType,
+    CRAllocationStrategyType,
+    CRTypeType,
+    DeviceCgroupPermissionType,
+    EFSAuthorizationConfigIAMType,
+    EFSTransitEncryptionType,
+    JobStatusType,
+    JQStateType,
+    JQStatusType,
+    LogDriverType,
+    PlatformCapabilityType,
+    ResourceTypeType,
+    RetryActionType,
 )
 
 if sys.version_info >= (3, 8):
@@ -164,9 +164,9 @@ _OptionalComputeEnvironmentDetailTypeDef = TypedDict(
     "_OptionalComputeEnvironmentDetailTypeDef",
     {
         "tags": Dict[str, str],
-        "type": CEType,
-        "state": CEState,
-        "status": CEStatus,
+        "type": CETypeType,
+        "state": CEStateType,
+        "status": CEStatusType,
         "statusReason": str,
         "computeResources": "ComputeResourceTypeDef",
         "serviceRole": str,
@@ -192,7 +192,7 @@ ComputeEnvironmentOrderTypeDef = TypedDict(
 _RequiredComputeResourceTypeDef = TypedDict(
     "_RequiredComputeResourceTypeDef",
     {
-        "type": CRType,
+        "type": CRTypeType,
         "maxvCpus": int,
         "subnets": List[str],
     },
@@ -200,7 +200,7 @@ _RequiredComputeResourceTypeDef = TypedDict(
 _OptionalComputeResourceTypeDef = TypedDict(
     "_OptionalComputeResourceTypeDef",
     {
-        "allocationStrategy": CRAllocationStrategy,
+        "allocationStrategy": CRAllocationStrategyType,
         "minvCpus": int,
         "desiredvCpus": int,
         "instanceTypes": List[str],
@@ -379,7 +379,7 @@ _OptionalDeviceTypeDef = TypedDict(
     "_OptionalDeviceTypeDef",
     {
         "containerPath": str,
-        "permissions": List[DeviceCgroupPermission],
+        "permissions": List[DeviceCgroupPermissionType],
     },
     total=False,
 )
@@ -393,7 +393,7 @@ EFSAuthorizationConfigTypeDef = TypedDict(
     "EFSAuthorizationConfigTypeDef",
     {
         "accessPointId": str,
-        "iam": EFSAuthorizationConfigIAM,
+        "iam": EFSAuthorizationConfigIAMType,
     },
     total=False,
 )
@@ -408,7 +408,7 @@ _OptionalEFSVolumeConfigurationTypeDef = TypedDict(
     "_OptionalEFSVolumeConfigurationTypeDef",
     {
         "rootDirectory": str,
-        "transitEncryption": EFSTransitEncryption,
+        "transitEncryption": EFSTransitEncryptionType,
         "transitEncryptionPort": int,
         "authorizationConfig": "EFSAuthorizationConfigTypeDef",
     },
@@ -444,7 +444,7 @@ class Ec2ConfigurationTypeDef(_RequiredEc2ConfigurationTypeDef, _OptionalEc2Conf
 _RequiredEvaluateOnExitTypeDef = TypedDict(
     "_RequiredEvaluateOnExitTypeDef",
     {
-        "action": RetryAction,
+        "action": RetryActionType,
     },
 )
 _OptionalEvaluateOnExitTypeDef = TypedDict(
@@ -498,7 +498,7 @@ _OptionalJobDefinitionTypeDef = TypedDict(
         "nodeProperties": "NodePropertiesTypeDef",
         "tags": Dict[str, str],
         "propagateTags": bool,
-        "platformCapabilities": List[PlatformCapability],
+        "platformCapabilities": List[PlatformCapabilityType],
     },
     total=False,
 )
@@ -512,7 +512,7 @@ JobDependencyTypeDef = TypedDict(
     "JobDependencyTypeDef",
     {
         "jobId": str,
-        "type": ArrayJobDependency,
+        "type": ArrayJobDependencyType,
     },
     total=False,
 )
@@ -523,7 +523,7 @@ _RequiredJobDetailTypeDef = TypedDict(
         "jobName": str,
         "jobId": str,
         "jobQueue": str,
-        "status": JobStatus,
+        "status": JobStatusType,
         "startedAt": int,
         "jobDefinition": str,
     },
@@ -546,7 +546,7 @@ _OptionalJobDetailTypeDef = TypedDict(
         "timeout": "JobTimeoutTypeDef",
         "tags": Dict[str, str],
         "propagateTags": bool,
-        "platformCapabilities": List[PlatformCapability],
+        "platformCapabilities": List[PlatformCapabilityType],
     },
     total=False,
 )
@@ -561,7 +561,7 @@ _RequiredJobQueueDetailTypeDef = TypedDict(
     {
         "jobQueueName": str,
         "jobQueueArn": str,
-        "state": JQState,
+        "state": JQStateType,
         "priority": int,
         "computeEnvironmentOrder": List["ComputeEnvironmentOrderTypeDef"],
     },
@@ -569,7 +569,7 @@ _RequiredJobQueueDetailTypeDef = TypedDict(
 _OptionalJobQueueDetailTypeDef = TypedDict(
     "_OptionalJobQueueDetailTypeDef",
     {
-        "status": JQStatus,
+        "status": JQStatusType,
         "statusReason": str,
         "tags": Dict[str, str],
     },
@@ -593,7 +593,7 @@ _OptionalJobSummaryTypeDef = TypedDict(
     {
         "jobArn": str,
         "createdAt": int,
-        "status": JobStatus,
+        "status": JobStatusType,
         "statusReason": str,
         "startedAt": int,
         "stoppedAt": int,
@@ -679,7 +679,7 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 _RequiredLogConfigurationTypeDef = TypedDict(
     "_RequiredLogConfigurationTypeDef",
     {
-        "logDriver": LogDriver,
+        "logDriver": LogDriverType,
     },
 )
 _OptionalLogConfigurationTypeDef = TypedDict(
@@ -709,7 +709,7 @@ MountPointTypeDef = TypedDict(
 NetworkConfigurationTypeDef = TypedDict(
     "NetworkConfigurationTypeDef",
     {
-        "assignPublicIp": AssignPublicIp,
+        "assignPublicIp": AssignPublicIpType,
     },
     total=False,
 )
@@ -826,7 +826,7 @@ ResourceRequirementTypeDef = TypedDict(
     "ResourceRequirementTypeDef",
     {
         "value": str,
-        "type": ResourceType,
+        "type": ResourceTypeType,
     },
 )
 
